import { ReactPropsWithoutRef, IComponent } from '@clutchd/component';

/**
 * Type to define `Layout` props shared by all component
 */
interface ILayoutProps$1 {
    col?: boolean;
    padding?: boolean;
    row?: boolean;
}

/**
 * Type to define `Container` component
 */
declare type IContainer = typeof Container;
/**
 * Type to define `Container` props
 */
interface IContainerProps extends ILayoutProps$1, ReactPropsWithoutRef<IComponent["div"]> {
}
/**
 * `Container` - A generic flex container used to create consistent layouts
 * @param props `IContainerProps` used to render this `Container`
 * @returns `Container` component
 */
declare function Container({ col, padding, row, ...props }: IContainerProps): JSX.Element;

/**
 * Type to define `Content` component
 */
declare type IContent = typeof Content;
/**
 * Type to define `Content` props
 */
interface IContentProps extends ILayoutProps$1, ReactPropsWithoutRef<IComponent["main"]> {
}
/**
 * `Content` - A `Container` designed to contain a page's primary content. Renders as a `main` element
 * @param props `IContentProps` used to render this `Content`
 * @returns `Content` component
 */
declare function Content({ col, padding, row, ...props }: IContentProps): JSX.Element;

/**
 * Type to define `Footer` component
 */
declare type IFooter = typeof Footer;
/**
 * Type to define `Footer` props
 */
interface IFooterProps extends ILayoutProps$1, ReactPropsWithoutRef<IComponent["footer"]> {
}
/**
 * `Footer` - A `Container` designed to contain a page's footer content. Renders as a `footer` element
 * @param props `IFooterProps` used to render this `Footer`
 * @returns `Footer` component
 */
declare function Footer({ col, padding, row, ...props }: IFooterProps): JSX.Element;

/**
 * Type to define `Header` component
 */
declare type IHeader = typeof Header;
/**
 * Type to define `Header` props
 */
interface IHeaderProps extends ILayoutProps$1, ReactPropsWithoutRef<IComponent["header"]> {
}
/**
 * `Header` - A `Container` designed to contain a page's header content. Renders as a `header` element
 * @param props `IHeaderProps` used to render this `Header`
 * @returns `Header` component
 */
declare function Header({ col, padding, row, ...props }: IHeaderProps): JSX.Element;

/**
 * Type to define `Page` component
 */
declare type IPage = typeof Page;
/**
 * Type to define `Page` props
 */
interface IPageProps extends ILayoutProps$1, ReactPropsWithoutRef<IComponent["header"]> {
}
/**
 * `Page` - A `Container` designed to contain an entire page. Renders as a `div` element that fills the screen
 * @param props `IPageProps` used to render this `Page`
 * @returns `Page` component
 */
declare function Page({ col, padding, row, ...props }: IPageProps): JSX.Element;

/**
 * Type to define `Layout` component
 */
declare type ILayout = {
    Container: IContainer;
    Content: IContent;
    Footer: IFooter;
    Header: IHeader;
    Page: IPage;
};
/**
 * Type to define `Layout` props
 */
interface ILayoutProps {
    IContainerProps: IContainerProps;
    IContentProps: IContentProps;
    IFooterProps: IFooterProps;
    IHeaderProps: IHeaderProps;
    IPageProps: IPageProps;
}
/**
 * `Layout` - A component used to quickly setup various layouts and containers
 */
declare const Layout: ILayout;

export { ILayout, ILayoutProps, Layout };
